Polemarch documantation

# Polemarch documentation

# Welcome to Polemarch’s documentation!

Polemarch is service for orchestration infrastructure by ansible. Simply WEB gui for orchestration infrastructure by ansible playbooks.

You could find latest releases there. Source code you could find in official repository.

Contact to us on any questions or report bugs.

Contents:

- Installation and quick start
  - Red Hat/CentOS installation
  - Ubuntu/Debian installation
  - Quickstart
  - Backup
  - Update
  - Migrate
  - Create superuser
  - Change password
- Run from source distribution
- Configuration manual
  - Introduction
  - Polemarch clustering overview
  - Main settings
  - Database settings
  - Cache settings
  - Locks settings
  - Rpc settings
  - Web settings
  - Production web settings
  - Installation of additional packages to Polemarch
- GUI workflow
  - Welcome to Polemarch GUI
  - Before you start
  - Inventories
  - Groups
  - Hosts
  - Projects
  - Execution of modules
  - Execution of playbooks
  - Templates
  - Options
  - Periodic tasks
  - Search
- Rest API
  - Pagination
  - Hosts
  - Groups
  - Inventories
  - Projects
  - Tasks
  - Periodic tasks
  - Templates
  - History records
  - Ansible
  - Statistic list
  - Variables
  - Sublists
  - Hooks
  - Token
  - Users
  - Teams (Polemarch+ only)
  - ACL system (Polemarch+ only)
  - License (Polemarch+ only)
- How to participate
- VST Consulting contributor agreement
  - 1. Definitions
  - 2. Copyright Assignment, License and Waiver
  - 3. Patent License
  - 4. Your Representation and Warranties.
  - 5. Intellectual Property
  - Miscellaneous